<?php

/**
 * @name      NoFollow
 * @copyright NoFollow contributors
 * @license   BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.2
 *
 */

// Thats just no to you
if (!defined('ELK'))
	die('No access...');

class NoFollow_Integrate
{
	protected $whitelist = array();
	protected static $instance = null;

	public static function integrate_bbc_buttons()
	{
		loadJavascriptfile('nofollow.sceditor.bbcode.js');
	}

	public static function integrate_bbc_codes(&$codes)
	{
		$found = 0;
		$code = null;

		// url tags are the latest two, no need to parse the whole array,
		// start from the bottom and stop when you catch them. :P
		for ($i = count($codes) - 1; $i > 0; $i--)
		{
			$code = &$codes[$i];
			if ($code['tag'] == 'url')
			{
				switch ($code['type'])
				{
					case 'unparsed_content':
						$found++;
						$code['content'] = '<a href="$1" class="bbc_link" rel="nofollow" target="_blank">$1</a>';
						break;
					case 'unparsed_equals':
						$found++;
						$code['before'] = '<a href="$1" class="bbc_link" rel="nofollow" target="_blank">';
						break;
				}
				if ($found === 2)
				{
					break;
				}
			}
		}
		$codes[] = array(
			'tag' => 'url',
			'parameters' => array(
				'url' => array(
					'match' => '([^\s\]]+\]?)',
					'validate' => create_function('$param', '
						$param = strtr($param, array(\'<br />\' => \'\'));
						if (strpos($param, \'http://\') !== 0 && strpos($param, \'https://\') !== 0)
						{
							$param = \'http://\' . $param;
						}
					')
				),
				'nofollow' => array(
					'match' => '(nofollow|dofollow)',
					'validate' => create_function('$param', '
						// This if block is a remnant of when I was thinking to allow
						// a nofollow=follow parameter value.
						// I\'m not yet sure I don\'t want to, so I\'ll leave it here.
						if ($param === \'nofollow\')
						{
							return \'rel="nofollow"\';
						}
						else
						{
							return \'\';
						}
					')
				),
			),
			'before' => '<a href="{url}" class="bbc_link"{nofollow} target="_blank">',
			'after' => '</a>',
		);
	}

	public static function integrate_preparse_code(&$part)
	{
		static $allowed = null;

		if ($allowed === null)
		{
			$allowed = allowedTo('post_nofollow');
		}

		if ($allowed === true)
		{
			$fix = array(
				'~\[url\](.*?)\[/url\]~' => '[url url=$1 nofollow=dofollow]$1[/url]',
				'~\[url=([^\s\]]+?)\](.*?)\[/url\]~' => '[url url=$1 nofollow=dofollow]$2[/url]',
			);
		}
		else
		{
			$fix = array(
				'~\[url\](.*?)\[/url\]~' => '[url url=$1 nofollow=nofollow]$1[/url]',
				'~\[url=([^\s\]]+?)\](.*?)\[/url\]~' => '[url url=$1 nofollow=nofollow]$2[/url]',
				'~\[url url=([^\s\]]+?)\s*nofollow=dofollow\s*\](.*?)\[/url\]~' => '[url url=$1 nofollow=nofollow]$2[/url]',
				'~\[url\s*nofollow=dofollow\s*url=([^\s\]]+?)\](.*?)\[/url\]~' => '[url url=$1 nofollow=nofollow]$2[/url]',
			);
		}
		$part = preg_replace(array_keys($fix), $fix, $part);
	}

	public static function integrate_load_permissions(&$permissionGroups, &$permissionList)
	{
		loadLanguage('NoFollow');
		$permissionList['membergroup']['post_nofollow'] = array(false, 'general');
	}

	public static function integrate_post_parsebbc(&$message)
	{
		global $modSettings;

		if (empty($modSettings['nofollow_whitelist']))
			return;

		if (self::$instance === null)
		{
			self::$instance = new NoFollow_Integrate((array) json_decode($modSettings['nofollow_whitelist']), !empty($modSettings['nofollow_internal']));
		}

		$message = preg_replace_callback('~<a href="(.*?)" class="bbc_link" rel="nofollow"(?: target=".*?")?>~', array(self::$instance, 'replace_callback'), $message);
	}

	public static function integrate_general_mod_settings(&$config_vars)
	{
		global $modSettings, $txt;

		loadLanguage('NoFollow');

		if (!empty($modSettings['nofollow_whitelist']))
		{
			$modSettings['nofollow_whitelist'] = implode("\n", json_decode($modSettings['nofollow_whitelist']));
		}
		$config_vars[] = array('large_text', 'nofollow_whitelist', 'subtext' => $txt['nofollow_whitelist_desc']);
		$config_vars[] = array('check', 'nofollow_internal');
	}

	public static function integrate_save_general_mod_settings()
	{
		$_POST['nofollow_whitelist'] = json_encode(array_filter(array_map('Util::htmlspecialchars', array_map('trim', array_unique(explode("\n", $_POST['nofollow_whitelist']))))));
	}

	public function __construct($whitelist, $nofollow_internal = false)
	{
		global $boardurl;

		if ($nofollow_internal === true)
		{
			$parse = parse_url($boardurl);
			$whitelist[] = $parse['host'];
		}

		$this->whitelist = array_unique($whitelist);
	}

	public function replace_callback($match)
	{
		$parsed = parse_url($match[1]);
		foreach ($this->whitelist as $valid_domain)
		{
			if (substr($parsed['host'], -strlen($valid_domain)) === $valid_domain)
			{
				return str_replace(' rel="nofollow"', '', $match[0]);
			}
		}

		return $match[0];
	}
}