<?php

/**
 * TestCase class for NoFollow_Integrate class.
 *
 * Tests adding and removing errors and few other options
 */
class TestNoFollow extends PHPUnit_Framework_TestCase
{
	protected static $_allowed = false;
	protected $NoFollowTests;

	/**
	 * Prepare what is necessary to use in these tests.
	 *
	 * setUp() is run automatically by the testing framework before each test method.
	 */
	public function setUp()
	{
		define('ELK', 'TEST');
		require_once('./NoFollow.integrate.php');

		$this->NoFollowTests = array(
			array(
				'input' => '[url]http://www.testing.com[/url]',
				'output_allowed' => '[url url=http://www.testing.com nofollow=dofollow]http://www.testing.com[/url]',
				'output_not_allowed' => '[url url=http://www.testing.com nofollow=nofollow]http://www.testing.com[/url]',
				'error_msg' => '1st test',
			),
			array(
				'input' => '[url=http://www.testing.com]some text[/url]',
				'output_allowed' => '[url url=http://www.testing.com nofollow=dofollow]some text[/url]',
				'output_not_allowed' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'error_msg' => '2nd test',
			),
			array(
				'input' => '[url url=http://www.testing.com nofollow=dofollow]some text[/url]',
				'output_allowed' => '[url url=http://www.testing.com nofollow=dofollow]some text[/url]',
				'output_not_allowed' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'error_msg' => '3rd test',
			),
			array(
				'input' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'output_allowed' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'output_not_allowed' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'error_msg' => '4th test',
			),
			array(
				'input' => '[url nofollow=dofollow url=http://www.testing.com]some text[/url]',
				'output_allowed' => '[url nofollow=dofollow url=http://www.testing.com]some text[/url]',
				'output_not_allowed' => '[url url=http://www.testing.com nofollow=nofollow]some text[/url]',
				'error_msg' => '5th test',
			),
			array(
				'input' => '[url nofollow=nofollow url=http://www.testing.com]some text[/url]',
				'output_allowed' => '[url nofollow=nofollow url=http://www.testing.com]some text[/url]',
				'output_not_allowed' => '[url nofollow=nofollow url=http://www.testing.com]some text[/url]',
				'error_msg' => '6th test',
			),
		);
	}

	/**
	 * We run this test in a seperate process to prevent the static variable to
	 * mess up things.
	 *
	 * @runInSeparateProcess
	 */
	public function testAllowedPreparse()
	{
		self::$_allowed = 'allowed';

		foreach ($this->NoFollowTests as $test)
		{
			$part = $test['input'];
			NoFollow_Integrate::integrate_preparse_code($part);
			$this->assertEquals($test['output_' . self::$_allowed], $part, $test['error_msg'] . ' Allowed: ' . self::$_allowed);
		}
	}

	/**
	 * We run this test in a seperate process to prevent the static variable to
	 * mess up things.
	 *
	 * @runInSeparateProcess
	 */
	public function testNotAllowedPreparse()
	{
		self::$_allowed = 'not_allowed';

		foreach ($this->NoFollowTests as $test)
		{
			$part = $test['input'];
			NoFollow_Integrate::integrate_preparse_code($part);
			$this->assertEquals($test['output_' . self::$_allowed], $part, $test['error_msg'] . ' Allowed: ' . self::$_allowed);
		}
	}

	public static function allowedTo()
	{
		return self::$_allowed === 'allowed';
	}
}

function allowedTo()
{
	return TestNoFollow::allowedTo();
}